### Name: calculatePathwayStatistics
### Title: Calculate the NTk and NEk statistics
### Aliases: calculate.NTk calculate.NEk
### Keywords: array htest

### ** Examples

## Load in expression data and select the probe sets have expression
## values greater than the trimmed mean in at least 1 out of 49 arrays
data(MuscleData)
sf <- apply(MuscleData, 2, mean, tr = 0.025)
temp <- sweep(MuscleData, 2, sf, FUN = '/')
ind.pskeep <- which(rowSums(temp > 1) > 0)
tabMD <- MuscleData[ind.pskeep, ]
probeID <- names(ind.pskeep)

rm(temp)

## Select the data to study: IBM vs. NORM _or_ DM vs. NORM
compIBM <- TRUE

if( compIBM == TRUE )  {
  tab <- tabMD[,c(index.NORM, index.IBM)]
  phenotype <- c(rep.int(0,length(index.NORM)), rep.int(1,length(index.IBM)))
}else  {
  tab <- tabMD[,c(index.NORM, index.DM)]
  phenotype <- c(rep.int(0,length(index.NORM)), rep.int(1,length(index.DM)))
}

## Prepare the pathways to analyze
data(GenesetsU133a)
gsList <- selectGeneSets(G, probeID, 20, 500)

## Calculate NTk and weighted NEk for each gene set
## * Use a higher nsim (e.g., 2500) value for more reproducible results
nsim <- 100
ngroups <- 2
verbose <- TRUE
weightType <- "constant"
methodNames <- c("NTk", "NEk")
npath = 25
res.NTk <- calculate.NTk(tab, phenotype, gsList, nsim, ngroups, verbose)
res.NEk <- calculate.NEk(tab, phenotype, gsList, nsim, weightType,
                         ngroups, verbose)

## Summarize results
res.pathways <- rankPathways(res.NTk, res.NEk, G, gsList, methodNames,
                             npath)
print(res.pathways)

## Get more information about the probe sets' means and other statistics
## for the top pathway in res.pathways
topIndex <- res.pathways$IndexG[1]
res.topPathway <- getPathwayStatistics(tab, phenotype, G, topIndex,
                                       ngroups, NULL, FALSE)
print(res.topPathway[[1]])



